# Copyright 2023-SomItCoop SCCL(<https://gitlab.com/somitcoop>)
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl.html).
{
    "name": "ODOO helpdesk tickets with document pages",
    "version": "16.0.1.1.2",
    "depends": [
        "helpdesk_mgmt",
        "document_page",
        "document_page_tag",
    ],
    "author": """
        Som It Cooperatiu SCCL,
        Som Connexió SCCL,
        Odoo Community Association (OCA)",
    """,
    "category": "Auth",
    "website": "https://gitlab.com/somitcoop/erp-research/odoo-helpdesk",
    "license": "AGPL-3",
    "summary": """
        ODOO module to relate helpdesk tickets with knowledge document pages.
    """,
    "data": [
        "views/document_page.xml",
        "views/helpdesk_ticket.xml",
    ],
    "demo": [],
    "application": False,
    "installable": True,
}



from odoo.tests import common, tagged


@tagged("post_install", "helpdesk_ticket_document_pages")
class TestHelpdeskTicket(common.TransactionCase):
    def test_open_related_document_pages(self):
        ticket = self.env.ref("helpdesk_mgmt.helpdesk_ticket_3")
        ticket_roaming_tag = self.env["helpdesk.ticket.tag"].create(
            {"name": "Roaming issue"}
        )
        document_page1 = self.env.ref("document_page.demo_page1")
        document_page3 = self.env.ref("document_page.demo_page3")
        custom_tree_view = self.env.ref(
            "helpdesk_ticket_document_pages.document_page_tree_new_target"
        )
        custom_form_view = self.env.ref(
            "helpdesk_ticket_document_pages.document_page_look_up_form_view"
        )

        # Assign ticket tag to ticket
        ticket.tag_ids = [(4, ticket_roaming_tag.id)]

        # Assign ticket tag to document pages
        document_page1.ticket_tag_ids = [(4, ticket_roaming_tag.id)]
        document_page3.ticket_tag_ids = [(4, ticket_roaming_tag.id)]

        action_result = ticket.open_related_document_pages()

        self.assertEqual(action_result["name"], "Document Pages")
        self.assertEqual(action_result["type"], "ir.actions.act_window")
        self.assertEqual(action_result["res_model"], "document.page")
        self.assertEqual(
            action_result["views"],
            [[custom_tree_view.id, "tree"], [custom_form_view.id, "form"]],
        )
        self.assertEqual(
            action_result["domain"],
            [("id", "in", [document_page1.id, document_page3.id])],
        )



from odoo import models


class HelpdeskTicket(models.Model):
    _inherit = "helpdesk.ticket"

    def open_related_document_pages(self):
        document_page_ids = self.env["document.page"].search(
            [
                ("ticket_tag_ids", "in", self.tag_ids.ids),
            ]
        )
        return (
            self.env["document.page"]
            .with_context(document_page_ids=document_page_ids.ids)
            .open_tree_view_target_new()
        )



from odoo import models, fields, _


class DocumentPage(models.Model):
    _inherit = "document.page"

    ticket_tag_ids = fields.Many2many(
        comodel_name="helpdesk.ticket.tag",
        string="Related ticket tags",
    )

    def look_up_view(self):
        custom_form_view = self.env.ref(
            "helpdesk_ticket_document_pages.document_page_look_up_form_view"
        )
        return {
            "name": _("Document Page"),
            "type": "ir.actions.act_window",
            "res_model": "document.page",
            "res_id": self.id,
            "view_mode": "form",
            "views": [[custom_form_view.id, "form"]],
            "target": "new",
            "flags": {"mode": "readonly"},
            "context": {
                "document_page_ids": self.env.context.get("document_page_ids", [])
            },
        }

    def open_tree_view_target_new(self):
        custom_tree_view = self.env.ref(
            "helpdesk_ticket_document_pages.document_page_tree_new_target"
        )
        custom_form_view = self.env.ref(
            "helpdesk_ticket_document_pages.document_page_look_up_form_view"
        )

        return {
            "name": _("Document Pages"),
            "type": "ir.actions.act_window",
            "res_model": "document.page",
            "view_mode": "tree,form",
            "views": [[custom_tree_view.id, "tree"], [custom_form_view.id, "form"]],
            "target": "new",
            "domain": [("id", "in", self.env.context.get("document_page_ids", []))],
            "context": {
                "document_page_ids": self.env.context.get("document_page_ids", [])
            },
        }
